SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

CREATE PROCEDURE [dbo].[SaveEvaluationBaseResult] (
	@VCC VARCHAR(50) = NULL,
	@EVALUATION_PLAN_ID VARCHAR(100) = NULL,
	@ABILITY_TYPE VARCHAR(50) = NULL
) AS
BEGIN
	-- ESTE SP INSERTA LOS RESULT BASE DE UN PLAN AUTOMATICO/MIXTO
	SET NOCOUNT ON

	-- SETTEAMOS EL TYPE ABILITY COMO AUTOMATIC PO DEFECTO
	IF @ABILITY_TYPE IS NULL SET @ABILITY_TYPE = 'AUTOMATIC'
	
	-- EMULAMOS UNA NUEVA TABLA VARIABLE PARA OBTENER LOS REGISTROS UNICOS QUE INSERTAREMOS EN LA TABLA EVALUATION_RESULT
	--  ORDENANDO POR SECTION Y PART
	;WITH CTE AS (
		SELECT IEP.[Instance]									'vcc', 
				IEP.[IdCampaign]								'IdCampaign',
				IEP.[IdInteraction]								'IdInteraction',
				IEP.[IdAgent]									'IdAgent', 
				EP.[IdEvaluationFormat]							'IdEvaluationFormat', 
				EF.[MinQualificationAcceptable]					'MinQualificationAcceptable',
				AEF.[IdGroup]									'IdGroup', 
				AEF.[IdSubGroup]								'IdSubGroup', 
				AEF.[IdAbility]									'IdAbility',
				AEF.[Score]										'MaxAbilityScore',
				S.[Value]										'AbilityInnerScore',
				EP.[ID]											'IdEvaluationPlan', 
				S.[Description]									'ScoreDescription', 
				IEP.[IdCampaign]								'CampaignDescription', 
				IEP.[IdAgent]									'AgentDescription',
				IEP.[InteractionDateStart]						'InteractionDateini', 
				IEP.[InteractionDateEnd]						'InteractionDatefin', 
				IEP.[ContactId]									'InteractionAddress', 
				AEF.[Order]										'AbilityOrder', 
				IEP.[InteractionType]							'InteractionType', 
				AEF.[ID]										'IdAbilityEvaluationFormat', 
				AEF.[Conditional]								'Conditional', 
				RN = ROW_NUMBER() OVER(PARTITION BY IEP.[IdCampaign],
													IEP.[IdInteraction],
													IEP.[IdAgent], 
													EP.[IdEvaluationFormat], 
													EF.[MinQualificationAcceptable],
													AEF.[IdGroup], 
													AEF.[IdSubGroup], 
													AEF.[IdAbility],
													S.[Value], 
													S.[Description], 
													IEP.[IdCampaign], 
													IEP.[IdAgent],
													IEP.[InteractionDateStart], 
													IEP.[InteractionDateEnd], 
													AEF.[Order], 
													IEP.[InteractionType], 
													AEF.[ID], 
													AEF.[Conditional]
										ORDER BY IEP.[InteractionSection] ASC, IEP.[InteractionPart] ASC) 
			FROM EvaluationPlan EP (NOLOCK)
			LEFT JOIN EvaluationFormat EF (NOLOCK) 
				ON EF.[Instance] = EP.[Instance]
					AND EF.[ID] = EP.[IdEvaluationFormat]
			LEFT JOIN InteractionEvaluationPlan IEP (NOLOCK)
				ON IEP.[Instance] = EP.[Instance]
					AND IEP.[IdEvaluationPlan] = EP.[ID]
			LEFT JOIN AbilityEvaluationFormat AEF (NOLOCK)
				ON AEF.[Instance] = EP.[Instance]
					AND AEF.[IdEvaluationFormat] = EF.[ID]
			LEFT JOIN Ability A (NOLOCK) 
				ON A.[Instance] = EP.[Instance]
					AND A.[ID] = AEF.[IdAbility]
			LEFT JOIN Intent I (NOLOCK) 
				ON I.[VCC] = EP.[Instance]
					AND I.[IntentId] = A.[QueryName]
			LEFT JOIN [dbo].[Score] S (NOLOCK) 
				ON S.[Instance] = IEP.[Instance]
					AND S.[IdAbility] = A.[ID]
					AND S.[Value] = IIF(A.[IsNegative] = 1, 100, 0)
			LEFT JOIN [dbo].[EvaluationResult] ER (NOLOCK) 
				ON ER.[Instance] = IEP.[Instance]
					AND ER.[IdEvaluationPlan] = IEP.[IdEvaluationPlan]
					AND ER.[IdAgent] = IEP.[IdAgent]
					AND ER.[IdAbilityEvaluationFormat] = AEF.[ID]
			LEFT JOIN [dbo].[Audio] AU(NOLOCK)
 			    ON  AU.[ID] = IEP.[IdInteraction]
				AND AU.[Section] = IEP.[InteractionSection]
				AND AU.[Part] = IEP.[InteractionPart]
			WHERE IEP.[IdInteraction] IS NOT NULL
				AND (
					-- (@ABILITY_TYPE = 'AUTOMATIC' AND I.[VCC] IS NOT NULL)
					(@ABILITY_TYPE = 'AUTOMATIC' AND A.[Type] = 'MANUAL_AUTOMATIC')
					OR
					-- (@ABILITY_TYPE = 'MANUAL' AND I.[VCC] IS NULL)
					(@ABILITY_TYPE = 'MANUAL' AND A.[Type] = 'MANUAL')
				)
				AND ER.[Instance] IS NULL
				AND EP.[ID] = @EVALUATION_PLAN_ID
				AND EP.[Instance] = @VCC
			    -- SI TIENE AUDIO DEBE ESTAR TRANSCRITO
			    AND (
					(
						AU.[ID] IS NOT NULL 
						AND 
						AU.[IsTranscribed] = 1
					)
					OR 
					IEP.[InteractionType] <> 'CALL'
				) 

	)

	-- INSERTAMOS SOLO LAS PRIMERAS OCURRENCIAS PARA CADA INTERACCION
	INSERT INTO [dbo].[EvaluationResult] (
		[Instance], [IdCampaign], [IdInteraction],
		[IdAgent], [IdEvaluationFormat], [MinQualificationAcceptable],
		[IdGroup], [IdSubGroup], [IdAbility],
		[Qualification], [OwnScore], [AbilityInnerScore], 
		[IdEvaluator], [EvaluationDate], [MaxAbilityScore], 
		[IdEvaluationPlan], [CreatedDate], [CreatedByUserId], 
		[LastModifiedDate], [LastModifiedByUserId], [TimeStamp], 
		[Comment], [NotApplies], [ScoreDescription], 
		[CampaignDescription], [AgentDescription], [InteractionDateini], 
		[InteractionDatefin], [InteractionAddress], [AbilityOrder], 
		[InteractionType], [IdAbilityEvaluationFormat],  [IdAuditor], 
		[Conditional]
	) 
		SELECT C.[vcc], C.[IdCampaign], C.[IdInteraction],
				C.[IdAgent], C.[IdEvaluationFormat], C.[MinQualificationAcceptable],
				C.[IdGroup], C.[IdSubGroup], C.[IdAbility],
				(C.[MaxAbilityScore] * C.[AbilityInnerScore] / 100), (C.[MaxAbilityScore] * C.[AbilityInnerScore] / 100), C.[AbilityInnerScore], 
				'SPEECH', GETUTCDATE(), C.[MaxAbilityScore], 
				C.[IdEvaluationPlan], GETUTCDATE(), 'SPEECH', 
				--'100', C.[IdEvaluationPlan], GETUTCDATE(),
				GETUTCDATE(), 'SPEECH', GETUTCDATE(), 
				NULL, '0', C.[ScoreDescription], 
				C.[CampaignDescription], C.[AgentDescription], C.[InteractionDateini], 
				C.[InteractionDatefin], C.[InteractionAddress], C.[AbilityOrder], 
				C.[InteractionType], C.[IdAbilityEvaluationFormat], 'SPEECH', 
				C.[Conditional]
			FROM CTE C 
			WHERE C.RN = 1
	
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
